# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from asteroid_odyssey.models.agents_execution_activity_action_completed_payload import AgentsExecutionActivityActionCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_action_failed_payload import AgentsExecutionActivityActionFailedPayload
from asteroid_odyssey.models.agents_execution_activity_action_started_payload import AgentsExecutionActivityActionStartedPayload
from asteroid_odyssey.models.agents_execution_activity_file_added_payload import AgentsExecutionActivityFileAddedPayload
from asteroid_odyssey.models.agents_execution_activity_generic_payload import AgentsExecutionActivityGenericPayload
from asteroid_odyssey.models.agents_execution_activity_playwright_script_generated_payload import AgentsExecutionActivityPlaywrightScriptGeneratedPayload
from asteroid_odyssey.models.agents_execution_activity_reasoning_payload import AgentsExecutionActivityReasoningPayload
from asteroid_odyssey.models.agents_execution_activity_status_changed_payload import AgentsExecutionActivityStatusChangedPayload
from asteroid_odyssey.models.agents_execution_activity_step_completed_payload import AgentsExecutionActivityStepCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_step_started_payload import AgentsExecutionActivityStepStartedPayload
from asteroid_odyssey.models.agents_execution_activity_transitioned_node_payload import AgentsExecutionActivityTransitionedNodePayload
from asteroid_odyssey.models.agents_execution_activity_user_message_received_payload import AgentsExecutionActivityUserMessageReceivedPayload
from asteroid_odyssey.models.agents_execution_activity_workflow_updated_payload import AgentsExecutionActivityWorkflowUpdatedPayload
from asteroid_odyssey.models.agents_execution_terminal_payload import AgentsExecutionTerminalPayload
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

AGENTSEXECUTIONACTIVITYPAYLOADUNION_ONE_OF_SCHEMAS = ["AgentsExecutionActivityActionCompletedPayload", "AgentsExecutionActivityActionFailedPayload", "AgentsExecutionActivityActionStartedPayload", "AgentsExecutionActivityFileAddedPayload", "AgentsExecutionActivityGenericPayload", "AgentsExecutionActivityPlaywrightScriptGeneratedPayload", "AgentsExecutionActivityReasoningPayload", "AgentsExecutionActivityStatusChangedPayload", "AgentsExecutionActivityStepCompletedPayload", "AgentsExecutionActivityStepStartedPayload", "AgentsExecutionActivityTransitionedNodePayload", "AgentsExecutionActivityUserMessageReceivedPayload", "AgentsExecutionActivityWorkflowUpdatedPayload", "AgentsExecutionTerminalPayload"]

class AgentsExecutionActivityPayloadUnion(BaseModel):
    """
    AgentsExecutionActivityPayloadUnion
    """
    # data type: AgentsExecutionTerminalPayload
    oneof_schema_1_validator: Optional[AgentsExecutionTerminalPayload] = None
    # data type: AgentsExecutionActivityGenericPayload
    oneof_schema_2_validator: Optional[AgentsExecutionActivityGenericPayload] = None
    # data type: AgentsExecutionActivityReasoningPayload
    oneof_schema_3_validator: Optional[AgentsExecutionActivityReasoningPayload] = None
    # data type: AgentsExecutionActivityStepStartedPayload
    oneof_schema_4_validator: Optional[AgentsExecutionActivityStepStartedPayload] = None
    # data type: AgentsExecutionActivityStepCompletedPayload
    oneof_schema_5_validator: Optional[AgentsExecutionActivityStepCompletedPayload] = None
    # data type: AgentsExecutionActivityTransitionedNodePayload
    oneof_schema_6_validator: Optional[AgentsExecutionActivityTransitionedNodePayload] = None
    # data type: AgentsExecutionActivityStatusChangedPayload
    oneof_schema_7_validator: Optional[AgentsExecutionActivityStatusChangedPayload] = None
    # data type: AgentsExecutionActivityActionStartedPayload
    oneof_schema_8_validator: Optional[AgentsExecutionActivityActionStartedPayload] = None
    # data type: AgentsExecutionActivityActionCompletedPayload
    oneof_schema_9_validator: Optional[AgentsExecutionActivityActionCompletedPayload] = None
    # data type: AgentsExecutionActivityActionFailedPayload
    oneof_schema_10_validator: Optional[AgentsExecutionActivityActionFailedPayload] = None
    # data type: AgentsExecutionActivityUserMessageReceivedPayload
    oneof_schema_11_validator: Optional[AgentsExecutionActivityUserMessageReceivedPayload] = None
    # data type: AgentsExecutionActivityFileAddedPayload
    oneof_schema_12_validator: Optional[AgentsExecutionActivityFileAddedPayload] = None
    # data type: AgentsExecutionActivityWorkflowUpdatedPayload
    oneof_schema_13_validator: Optional[AgentsExecutionActivityWorkflowUpdatedPayload] = None
    # data type: AgentsExecutionActivityPlaywrightScriptGeneratedPayload
    oneof_schema_14_validator: Optional[AgentsExecutionActivityPlaywrightScriptGeneratedPayload] = None
    actual_instance: Optional[Union[AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload]] = None
    one_of_schemas: Set[str] = { "AgentsExecutionActivityActionCompletedPayload", "AgentsExecutionActivityActionFailedPayload", "AgentsExecutionActivityActionStartedPayload", "AgentsExecutionActivityFileAddedPayload", "AgentsExecutionActivityGenericPayload", "AgentsExecutionActivityPlaywrightScriptGeneratedPayload", "AgentsExecutionActivityReasoningPayload", "AgentsExecutionActivityStatusChangedPayload", "AgentsExecutionActivityStepCompletedPayload", "AgentsExecutionActivityStepStartedPayload", "AgentsExecutionActivityTransitionedNodePayload", "AgentsExecutionActivityUserMessageReceivedPayload", "AgentsExecutionActivityWorkflowUpdatedPayload", "AgentsExecutionTerminalPayload" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = AgentsExecutionActivityPayloadUnion.model_construct()
        error_messages = []
        match = 0
        # validate data type: AgentsExecutionTerminalPayload
        if not isinstance(v, AgentsExecutionTerminalPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionTerminalPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityGenericPayload
        if not isinstance(v, AgentsExecutionActivityGenericPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityGenericPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityReasoningPayload
        if not isinstance(v, AgentsExecutionActivityReasoningPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityReasoningPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityStepStartedPayload
        if not isinstance(v, AgentsExecutionActivityStepStartedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityStepStartedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityStepCompletedPayload
        if not isinstance(v, AgentsExecutionActivityStepCompletedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityStepCompletedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityTransitionedNodePayload
        if not isinstance(v, AgentsExecutionActivityTransitionedNodePayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityTransitionedNodePayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityStatusChangedPayload
        if not isinstance(v, AgentsExecutionActivityStatusChangedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityStatusChangedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityActionStartedPayload
        if not isinstance(v, AgentsExecutionActivityActionStartedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityActionStartedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityActionCompletedPayload
        if not isinstance(v, AgentsExecutionActivityActionCompletedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityActionCompletedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityActionFailedPayload
        if not isinstance(v, AgentsExecutionActivityActionFailedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityActionFailedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityUserMessageReceivedPayload
        if not isinstance(v, AgentsExecutionActivityUserMessageReceivedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityUserMessageReceivedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityFileAddedPayload
        if not isinstance(v, AgentsExecutionActivityFileAddedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityFileAddedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityWorkflowUpdatedPayload
        if not isinstance(v, AgentsExecutionActivityWorkflowUpdatedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityWorkflowUpdatedPayload`")
        else:
            match += 1
        # validate data type: AgentsExecutionActivityPlaywrightScriptGeneratedPayload
        if not isinstance(v, AgentsExecutionActivityPlaywrightScriptGeneratedPayload):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionActivityPlaywrightScriptGeneratedPayload`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in AgentsExecutionActivityPayloadUnion with oneOf schemas: AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in AgentsExecutionActivityPayloadUnion with oneOf schemas: AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AgentsExecutionTerminalPayload
        try:
            instance.actual_instance = AgentsExecutionTerminalPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityGenericPayload
        try:
            instance.actual_instance = AgentsExecutionActivityGenericPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityReasoningPayload
        try:
            instance.actual_instance = AgentsExecutionActivityReasoningPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityStepStartedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityStepStartedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityStepCompletedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityStepCompletedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityTransitionedNodePayload
        try:
            instance.actual_instance = AgentsExecutionActivityTransitionedNodePayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityStatusChangedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityStatusChangedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityActionStartedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityActionStartedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityActionCompletedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityActionCompletedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityActionFailedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityActionFailedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityUserMessageReceivedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityUserMessageReceivedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityFileAddedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityFileAddedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityWorkflowUpdatedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityWorkflowUpdatedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionActivityPlaywrightScriptGeneratedPayload
        try:
            instance.actual_instance = AgentsExecutionActivityPlaywrightScriptGeneratedPayload.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into AgentsExecutionActivityPayloadUnion with oneOf schemas: AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into AgentsExecutionActivityPayloadUnion with oneOf schemas: AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AgentsExecutionActivityActionCompletedPayload, AgentsExecutionActivityActionFailedPayload, AgentsExecutionActivityActionStartedPayload, AgentsExecutionActivityFileAddedPayload, AgentsExecutionActivityGenericPayload, AgentsExecutionActivityPlaywrightScriptGeneratedPayload, AgentsExecutionActivityReasoningPayload, AgentsExecutionActivityStatusChangedPayload, AgentsExecutionActivityStepCompletedPayload, AgentsExecutionActivityStepStartedPayload, AgentsExecutionActivityTransitionedNodePayload, AgentsExecutionActivityUserMessageReceivedPayload, AgentsExecutionActivityWorkflowUpdatedPayload, AgentsExecutionTerminalPayload]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from asteroid_odyssey.models.agents_execution_comment import AgentsExecutionComment
from asteroid_odyssey.models.agents_execution_execution_result import AgentsExecutionExecutionResult
from asteroid_odyssey.models.agents_execution_human_label import AgentsExecutionHumanLabel
from asteroid_odyssey.models.agents_execution_status import AgentsExecutionStatus
from asteroid_odyssey.models.agents_execution_trigger_context import AgentsExecutionTriggerContext
from typing import Optional, Set
from typing_extensions import Self

class AgentsExecutionListItem(BaseModel):
    """
    Represents a single execution in a list view
    """ # noqa: E501
    id: StrictStr = Field(description="The unique identifier of the execution")
    agent_id: StrictStr = Field(description="The ID of the agent that was executed", alias="agentId")
    workflow_id: StrictStr = Field(description="The ID of the workflow that was executed", alias="workflowId")
    status: AgentsExecutionStatus = Field(description="The current status of the execution")
    created_at: datetime = Field(description="When the execution was created", alias="createdAt")
    terminal_at: Optional[datetime] = Field(default=None, description="When the execution reached a terminal state (if applicable)", alias="terminalAt")
    organization_id: StrictStr = Field(description="The organization this execution belongs to", alias="organizationId")
    agent_name: StrictStr = Field(description="The agent display name", alias="agentName")
    agent_profile_name: Optional[StrictStr] = Field(default=None, description="The name of the agent profile used for this execution (if any)", alias="agentProfileName")
    agent_profile_id: Optional[StrictStr] = Field(default=None, description="The ID of the agent profile used for this execution (if any)", alias="agentProfileId")
    inputs: Optional[Dict[str, Any]] = Field(default=None, description="Input variables used for this execution")
    execution_result: Optional[AgentsExecutionExecutionResult] = Field(default=None, description="Execution result with outcome, reasoning, and result data", alias="executionResult")
    duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Execution duration in seconds (only present for terminal executions)")
    human_labels: List[AgentsExecutionHumanLabel] = Field(description="Human-applied labels for this execution", alias="humanLabels")
    comments: List[AgentsExecutionComment] = Field(description="Comments on this execution")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Optional metadata key-value pairs attached to this execution")
    browser_recording_url: Optional[StrictStr] = Field(default=None, description="Browser recording URL (if a browser session was used and execution is terminal)", alias="browserRecordingUrl")
    browser_live_view_url: Optional[StrictStr] = Field(default=None, description="Browser live view URL for debugging (if a browser session is active and execution is running)", alias="browserLiveViewUrl")
    trigger_context: Optional[AgentsExecutionTriggerContext] = Field(default=None, description="Context about how and by whom this execution was triggered (discriminated by source)", alias="triggerContext")
    __properties: ClassVar[List[str]] = ["id", "agentId", "workflowId", "status", "createdAt", "terminalAt", "organizationId", "agentName", "agentProfileName", "agentProfileId", "inputs", "executionResult", "duration", "humanLabels", "comments", "metadata", "browserRecordingUrl", "browserLiveViewUrl", "triggerContext"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsExecutionListItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of execution_result
        if self.execution_result:
            _dict['executionResult'] = self.execution_result.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in human_labels (list)
        _items = []
        if self.human_labels:
            for _item_human_labels in self.human_labels:
                if _item_human_labels:
                    _items.append(_item_human_labels.to_dict())
            _dict['humanLabels'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in comments (list)
        _items = []
        if self.comments:
            for _item_comments in self.comments:
                if _item_comments:
                    _items.append(_item_comments.to_dict())
            _dict['comments'] = _items
        # override the default output from pydantic by calling `to_dict()` of trigger_context
        if self.trigger_context:
            _dict['triggerContext'] = self.trigger_context.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsExecutionListItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "agentId": obj.get("agentId"),
            "workflowId": obj.get("workflowId"),
            "status": obj.get("status"),
            "createdAt": obj.get("createdAt"),
            "terminalAt": obj.get("terminalAt"),
            "organizationId": obj.get("organizationId"),
            "agentName": obj.get("agentName"),
            "agentProfileName": obj.get("agentProfileName"),
            "agentProfileId": obj.get("agentProfileId"),
            "inputs": obj.get("inputs"),
            "executionResult": AgentsExecutionExecutionResult.from_dict(obj["executionResult"]) if obj.get("executionResult") is not None else None,
            "duration": obj.get("duration"),
            "humanLabels": [AgentsExecutionHumanLabel.from_dict(_item) for _item in obj["humanLabels"]] if obj.get("humanLabels") is not None else None,
            "comments": [AgentsExecutionComment.from_dict(_item) for _item in obj["comments"]] if obj.get("comments") is not None else None,
            "metadata": obj.get("metadata"),
            "browserRecordingUrl": obj.get("browserRecordingUrl"),
            "browserLiveViewUrl": obj.get("browserLiveViewUrl"),
            "triggerContext": AgentsExecutionTriggerContext.from_dict(obj["triggerContext"]) if obj.get("triggerContext") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AgentProfilesApi",
    "AgentsApi",
    "DocumentationApi",
    "ExecutionApi",
    "FilesApi",
    "SchemaApi",
    "WorkflowsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AgentList200Response",
    "AgentProfileClearBrowserCache200Response",
    "AgentProfilesList200Response",
    "AgentsAgentBase",
    "AgentsAgentExecuteAgentRequest",
    "AgentsAgentExecuteAgentResponse",
    "AgentsAgentSortField",
    "AgentsDocsSearchDocsRequest",
    "AgentsDocsSearchDocsResponse",
    "AgentsDocsSearchResult",
    "AgentsExecutionAPIKeyRef",
    "AgentsExecutionAPITriggerContext",
    "AgentsExecutionActionName",
    "AgentsExecutionActivity",
    "AgentsExecutionActivityActionCompletedInfo",
    "AgentsExecutionActivityActionCompletedPayload",
    "AgentsExecutionActivityActionFailedPayload",
    "AgentsExecutionActivityActionStartedInfo",
    "AgentsExecutionActivityActionStartedPayload",
    "AgentsExecutionActivityFileAddedPayload",
    "AgentsExecutionActivityGenericPayload",
    "AgentsExecutionActivityPayloadUnion",
    "AgentsExecutionActivityPlaywrightScriptGeneratedPayload",
    "AgentsExecutionActivityReasoningPayload",
    "AgentsExecutionActivityStatusChangedPayload",
    "AgentsExecutionActivityStepCompletedPayload",
    "AgentsExecutionActivityStepStartedPayload",
    "AgentsExecutionActivityTransitionedNodePayload",
    "AgentsExecutionActivityUserMessageReceivedPayload",
    "AgentsExecutionActivityWorkflowUpdatedPayload",
    "AgentsExecutionAgentQueryContextCompletedDetails",
    "AgentsExecutionAgentQueryContextStartedDetails",
    "AgentsExecutionAwaitingConfirmationPayload",
    "AgentsExecutionCancelReason",
    "AgentsExecutionCancelledPayload",
    "AgentsExecutionComment",
    "AgentsExecutionCompletedPayload",
    "AgentsExecutionElementFileUploadCompletedDetails",
    "AgentsExecutionExecutionResult",
    "AgentsExecutionExtApiCallCompletedDetails",
    "AgentsExecutionExtGetMailCompletedDetails",
    "AgentsExecutionFailedPayload",
    "AgentsExecutionFileListCompletedDetails",
    "AgentsExecutionFileReadCompletedDetails",
    "AgentsExecutionFileStageCompletedDetails",
    "AgentsExecutionHumanLabel",
    "AgentsExecutionLLMCallPurpose",
    "AgentsExecutionLLMCallStartedDetails",
    "AgentsExecutionListItem",
    "AgentsExecutionNavToCompletedDetails",
    "AgentsExecutionNavToStartedDetails",
    "AgentsExecutionNodeDetails",
    "AgentsExecutionNodeOutputItem",
    "AgentsExecutionObsSnapshotWithSelectorsCompletedDetails",
    "AgentsExecutionPausedPayload",
    "AgentsExecutionRulesDetails",
    "AgentsExecutionScheduleRef",
    "AgentsExecutionScheduleTriggerContext",
    "AgentsExecutionScratchpadReadCompletedDetails",
    "AgentsExecutionScratchpadReadStartedDetails",
    "AgentsExecutionScratchpadWriteCompletedDetails",
    "AgentsExecutionScratchpadWriteStartedDetails",
    "AgentsExecutionScriptEvalCompletedDetails",
    "AgentsExecutionScriptEvalStartedDetails",
    "AgentsExecutionScriptHybridPlaywrightCompletedDetails",
    "AgentsExecutionScriptHybridPlaywrightStartedDetails",
    "AgentsExecutionScriptPadRunFunctionCompletedDetails",
    "AgentsExecutionScriptPlaywrightCompletedDetails",
    "AgentsExecutionScriptPlaywrightStartedDetails",
    "AgentsExecutionScriptpadReadCompletedDetails",
    "AgentsExecutionScriptpadReadStartedDetails",
    "AgentsExecutionScriptpadRunFunctionStartedDetails",
    "AgentsExecutionScriptpadSearchReplaceCompletedDetails",
    "AgentsExecutionScriptpadSearchReplaceStartedDetails",
    "AgentsExecutionScriptpadWriteCompletedDetails",
    "AgentsExecutionSortField",
    "AgentsExecutionStatus",
    "AgentsExecutionTerminalPayload",
    "AgentsExecutionTransitionDetails",
    "AgentsExecutionTriggerContext",
    "AgentsExecutionTriggerRunner",
    "AgentsExecutionUITriggerContext",
    "AgentsExecutionUpdateExecutionStatusRequest",
    "AgentsExecutionUpdateType",
    "AgentsExecutionUpdateableStatus",
    "AgentsExecutionUserMessagesAddTextBody",
    "AgentsExecutionUtilGetDatetimeCompletedDetails",
    "AgentsExecutionUtilGetDatetimeStartedDetails",
    "AgentsExecutionWorkflowUpdate",
    "AgentsFilesFile",
    "AgentsFilesTempFile",
    "AgentsFilesTempFilesResponse",
    "AgentsGraphModelsAgentGraph",
    "AgentsGraphModelsNodesNode",
    "AgentsGraphModelsNodesNodePropertiesUnion",
    "AgentsGraphModelsNodesNodeType",
    "AgentsGraphModelsNodesPosition",
    "AgentsGraphModelsNodesPropertiesAPIMethod",
    "AgentsGraphModelsNodesPropertiesAPIProperties",
    "AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties",
    "AgentsGraphModelsNodesPropertiesIrisProperties",
    "AgentsGraphModelsNodesPropertiesOutputProperties",
    "AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVar",
    "AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVarType",
    "AgentsGraphModelsNodesPropertiesPlaywrightScriptProperties",
    "AgentsGraphModelsNodesPropertiesURLProperties",
    "AgentsGraphModelsNodesPropertiesVestaProperties",
    "AgentsGraphModelsSettings",
    "AgentsGraphModelsStickyNote",
    "AgentsGraphModelsTransitionsPropertiesIrisProperties",
    "AgentsGraphModelsTransitionsPropertiesOutcomeSuccessProperties",
    "AgentsGraphModelsTransitionsPropertiesSelectorProperties",
    "AgentsGraphModelsTransitionsTransition",
    "AgentsGraphModelsTransitionsTransitionPropertiesUnion",
    "AgentsGraphModelsTransitionsTransitionType",
    "AgentsGraphModelsTypeInputMethod",
    "AgentsProfileAgentProfile",
    "AgentsProfileCookie",
    "AgentsProfileCountryCode",
    "AgentsProfileCreateAgentProfileRequest",
    "AgentsProfileCredential",
    "AgentsProfileCredentialUpdate",
    "AgentsProfileCustomProxyConfigInput",
    "AgentsProfileCustomProxyConfigOutput",
    "AgentsProfileDuplicateAgentProfileRequest",
    "AgentsProfileOperatingSystem",
    "AgentsProfileProxyMode",
    "AgentsProfileProxyType",
    "AgentsProfileSameSite",
    "AgentsProfileSortField",
    "AgentsProfileUpdateAgentProfileRequest",
    "AgentsSchemaValidateSchemaRequest",
    "AgentsSchemaValidateSchemaResponse",
    "AgentsWorkflowBrowserProvider",
    "AgentsWorkflowBrowserTemplateConfig",
    "AgentsWorkflowCreateWorkflowRequest",
    "AgentsWorkflowCreateWorkflowResponse",
    "AgentsWorkflowEnvironmentTemplate",
    "AgentsWorkflowEnvironmentTemplateConfig",
    "AgentsWorkflowEnvironmentType",
    "AgentsWorkflowExecuteWorkflowRequest",
    "AgentsWorkflowExecuteWorkflowResponse",
    "AgentsWorkflowOsProvider",
    "AgentsWorkflowOsTemplateConfig",
    "AgentsWorkflowPublishWorkflowResponse",
    "AgentsWorkflowSyncExecutionRequest",
    "AgentsWorkflowSyncExecutionResponse",
    "AgentsWorkflowWorkflowRef",
    "AgentsWorkflowWorkflowSnapshot",
    "CommonBadRequestErrorBody",
    "CommonError",
    "CommonForbiddenErrorBody",
    "CommonInternalServerErrorBody",
    "CommonNotFoundErrorBody",
    "CommonOSError",
    "CommonSortDirection",
    "CommonUnauthorizedErrorBody",
    "ExecutionsList200Response",
    "Version",
]

# import apis into sdk package
from asteroid_odyssey.api.agent_profiles_api import AgentProfilesApi as AgentProfilesApi
from asteroid_odyssey.api.agents_api import AgentsApi as AgentsApi
from asteroid_odyssey.api.documentation_api import DocumentationApi as DocumentationApi
from asteroid_odyssey.api.execution_api import ExecutionApi as ExecutionApi
from asteroid_odyssey.api.files_api import FilesApi as FilesApi
from asteroid_odyssey.api.schema_api import SchemaApi as SchemaApi
from asteroid_odyssey.api.workflows_api import WorkflowsApi as WorkflowsApi

# import ApiClient
from asteroid_odyssey.api_response import ApiResponse as ApiResponse
from asteroid_odyssey.api_client import ApiClient as ApiClient
from asteroid_odyssey.configuration import Configuration as Configuration
from asteroid_odyssey.exceptions import OpenApiException as OpenApiException
from asteroid_odyssey.exceptions import ApiTypeError as ApiTypeError
from asteroid_odyssey.exceptions import ApiValueError as ApiValueError
from asteroid_odyssey.exceptions import ApiKeyError as ApiKeyError
from asteroid_odyssey.exceptions import ApiAttributeError as ApiAttributeError
from asteroid_odyssey.exceptions import ApiException as ApiException

# import models into sdk package
from asteroid_odyssey.models.agent_list200_response import AgentList200Response as AgentList200Response
from asteroid_odyssey.models.agent_profile_clear_browser_cache200_response import AgentProfileClearBrowserCache200Response as AgentProfileClearBrowserCache200Response
from asteroid_odyssey.models.agent_profiles_list200_response import AgentProfilesList200Response as AgentProfilesList200Response
from asteroid_odyssey.models.agents_agent_base import AgentsAgentBase as AgentsAgentBase
from asteroid_odyssey.models.agents_agent_execute_agent_request import AgentsAgentExecuteAgentRequest as AgentsAgentExecuteAgentRequest
from asteroid_odyssey.models.agents_agent_execute_agent_response import AgentsAgentExecuteAgentResponse as AgentsAgentExecuteAgentResponse
from asteroid_odyssey.models.agents_agent_sort_field import AgentsAgentSortField as AgentsAgentSortField
from asteroid_odyssey.models.agents_docs_search_docs_request import AgentsDocsSearchDocsRequest as AgentsDocsSearchDocsRequest
from asteroid_odyssey.models.agents_docs_search_docs_response import AgentsDocsSearchDocsResponse as AgentsDocsSearchDocsResponse
from asteroid_odyssey.models.agents_docs_search_result import AgentsDocsSearchResult as AgentsDocsSearchResult
from asteroid_odyssey.models.agents_execution_api_key_ref import AgentsExecutionAPIKeyRef as AgentsExecutionAPIKeyRef
from asteroid_odyssey.models.agents_execution_api_trigger_context import AgentsExecutionAPITriggerContext as AgentsExecutionAPITriggerContext
from asteroid_odyssey.models.agents_execution_action_name import AgentsExecutionActionName as AgentsExecutionActionName
from asteroid_odyssey.models.agents_execution_activity import AgentsExecutionActivity as AgentsExecutionActivity
from asteroid_odyssey.models.agents_execution_activity_action_completed_info import AgentsExecutionActivityActionCompletedInfo as AgentsExecutionActivityActionCompletedInfo
from asteroid_odyssey.models.agents_execution_activity_action_completed_payload import AgentsExecutionActivityActionCompletedPayload as AgentsExecutionActivityActionCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_action_failed_payload import AgentsExecutionActivityActionFailedPayload as AgentsExecutionActivityActionFailedPayload
from asteroid_odyssey.models.agents_execution_activity_action_started_info import AgentsExecutionActivityActionStartedInfo as AgentsExecutionActivityActionStartedInfo
from asteroid_odyssey.models.agents_execution_activity_action_started_payload import AgentsExecutionActivityActionStartedPayload as AgentsExecutionActivityActionStartedPayload
from asteroid_odyssey.models.agents_execution_activity_file_added_payload import AgentsExecutionActivityFileAddedPayload as AgentsExecutionActivityFileAddedPayload
from asteroid_odyssey.models.agents_execution_activity_generic_payload import AgentsExecutionActivityGenericPayload as AgentsExecutionActivityGenericPayload
from asteroid_odyssey.models.agents_execution_activity_payload_union import AgentsExecutionActivityPayloadUnion as AgentsExecutionActivityPayloadUnion
from asteroid_odyssey.models.agents_execution_activity_playwright_script_generated_payload import AgentsExecutionActivityPlaywrightScriptGeneratedPayload as AgentsExecutionActivityPlaywrightScriptGeneratedPayload
from asteroid_odyssey.models.agents_execution_activity_reasoning_payload import AgentsExecutionActivityReasoningPayload as AgentsExecutionActivityReasoningPayload
from asteroid_odyssey.models.agents_execution_activity_status_changed_payload import AgentsExecutionActivityStatusChangedPayload as AgentsExecutionActivityStatusChangedPayload
from asteroid_odyssey.models.agents_execution_activity_step_completed_payload import AgentsExecutionActivityStepCompletedPayload as AgentsExecutionActivityStepCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_step_started_payload import AgentsExecutionActivityStepStartedPayload as AgentsExecutionActivityStepStartedPayload
from asteroid_odyssey.models.agents_execution_activity_transitioned_node_payload import AgentsExecutionActivityTransitionedNodePayload as AgentsExecutionActivityTransitionedNodePayload
from asteroid_odyssey.models.agents_execution_activity_user_message_received_payload import AgentsExecutionActivityUserMessageReceivedPayload as AgentsExecutionActivityUserMessageReceivedPayload
from asteroid_odyssey.models.agents_execution_activity_workflow_updated_payload import AgentsExecutionActivityWorkflowUpdatedPayload as AgentsExecutionActivityWorkflowUpdatedPayload
from asteroid_odyssey.models.agents_execution_agent_query_context_completed_details import AgentsExecutionAgentQueryContextCompletedDetails as AgentsExecutionAgentQueryContextCompletedDetails
from asteroid_odyssey.models.agents_execution_agent_query_context_started_details import AgentsExecutionAgentQueryContextStartedDetails as AgentsExecutionAgentQueryContextStartedDetails
from asteroid_odyssey.models.agents_execution_awaiting_confirmation_payload import AgentsExecutionAwaitingConfirmationPayload as AgentsExecutionAwaitingConfirmationPayload
from asteroid_odyssey.models.agents_execution_cancel_reason import AgentsExecutionCancelReason as AgentsExecutionCancelReason
from asteroid_odyssey.models.agents_execution_cancelled_payload import AgentsExecutionCancelledPayload as AgentsExecutionCancelledPayload
from asteroid_odyssey.models.agents_execution_comment import AgentsExecutionComment as AgentsExecutionComment
from asteroid_odyssey.models.agents_execution_completed_payload import AgentsExecutionCompletedPayload as AgentsExecutionCompletedPayload
from asteroid_odyssey.models.agents_execution_element_file_upload_completed_details import AgentsExecutionElementFileUploadCompletedDetails as AgentsExecutionElementFileUploadCompletedDetails
from asteroid_odyssey.models.agents_execution_execution_result import AgentsExecutionExecutionResult as AgentsExecutionExecutionResult
from asteroid_odyssey.models.agents_execution_ext_api_call_completed_details import AgentsExecutionExtApiCallCompletedDetails as AgentsExecutionExtApiCallCompletedDetails
from asteroid_odyssey.models.agents_execution_ext_get_mail_completed_details import AgentsExecutionExtGetMailCompletedDetails as AgentsExecutionExtGetMailCompletedDetails
from asteroid_odyssey.models.agents_execution_failed_payload import AgentsExecutionFailedPayload as AgentsExecutionFailedPayload
from asteroid_odyssey.models.agents_execution_file_list_completed_details import AgentsExecutionFileListCompletedDetails as AgentsExecutionFileListCompletedDetails
from asteroid_odyssey.models.agents_execution_file_read_completed_details import AgentsExecutionFileReadCompletedDetails as AgentsExecutionFileReadCompletedDetails
from asteroid_odyssey.models.agents_execution_file_stage_completed_details import AgentsExecutionFileStageCompletedDetails as AgentsExecutionFileStageCompletedDetails
from asteroid_odyssey.models.agents_execution_human_label import AgentsExecutionHumanLabel as AgentsExecutionHumanLabel
from asteroid_odyssey.models.agents_execution_llm_call_purpose import AgentsExecutionLLMCallPurpose as AgentsExecutionLLMCallPurpose
from asteroid_odyssey.models.agents_execution_llm_call_started_details import AgentsExecutionLLMCallStartedDetails as AgentsExecutionLLMCallStartedDetails
from asteroid_odyssey.models.agents_execution_list_item import AgentsExecutionListItem as AgentsExecutionListItem
from asteroid_odyssey.models.agents_execution_nav_to_completed_details import AgentsExecutionNavToCompletedDetails as AgentsExecutionNavToCompletedDetails
from asteroid_odyssey.models.agents_execution_nav_to_started_details import AgentsExecutionNavToStartedDetails as AgentsExecutionNavToStartedDetails
from asteroid_odyssey.models.agents_execution_node_details import AgentsExecutionNodeDetails as AgentsExecutionNodeDetails
from asteroid_odyssey.models.agents_execution_node_output_item import AgentsExecutionNodeOutputItem as AgentsExecutionNodeOutputItem
from asteroid_odyssey.models.agents_execution_obs_snapshot_with_selectors_completed_details import AgentsExecutionObsSnapshotWithSelectorsCompletedDetails as AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
from asteroid_odyssey.models.agents_execution_paused_payload import AgentsExecutionPausedPayload as AgentsExecutionPausedPayload
from asteroid_odyssey.models.agents_execution_rules_details import AgentsExecutionRulesDetails as AgentsExecutionRulesDetails
from asteroid_odyssey.models.agents_execution_schedule_ref import AgentsExecutionScheduleRef as AgentsExecutionScheduleRef
from asteroid_odyssey.models.agents_execution_schedule_trigger_context import AgentsExecutionScheduleTriggerContext as AgentsExecutionScheduleTriggerContext
from asteroid_odyssey.models.agents_execution_scratchpad_read_completed_details import AgentsExecutionScratchpadReadCompletedDetails as AgentsExecutionScratchpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_read_started_details import AgentsExecutionScratchpadReadStartedDetails as AgentsExecutionScratchpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_completed_details import AgentsExecutionScratchpadWriteCompletedDetails as AgentsExecutionScratchpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_started_details import AgentsExecutionScratchpadWriteStartedDetails as AgentsExecutionScratchpadWriteStartedDetails
from asteroid_odyssey.models.agents_execution_script_eval_completed_details import AgentsExecutionScriptEvalCompletedDetails as AgentsExecutionScriptEvalCompletedDetails
from asteroid_odyssey.models.agents_execution_script_eval_started_details import AgentsExecutionScriptEvalStartedDetails as AgentsExecutionScriptEvalStartedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_completed_details import AgentsExecutionScriptHybridPlaywrightCompletedDetails as AgentsExecutionScriptHybridPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_started_details import AgentsExecutionScriptHybridPlaywrightStartedDetails as AgentsExecutionScriptHybridPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_script_pad_run_function_completed_details import AgentsExecutionScriptPadRunFunctionCompletedDetails as AgentsExecutionScriptPadRunFunctionCompletedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_completed_details import AgentsExecutionScriptPlaywrightCompletedDetails as AgentsExecutionScriptPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_started_details import AgentsExecutionScriptPlaywrightStartedDetails as AgentsExecutionScriptPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_completed_details import AgentsExecutionScriptpadReadCompletedDetails as AgentsExecutionScriptpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_started_details import AgentsExecutionScriptpadReadStartedDetails as AgentsExecutionScriptpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_run_function_started_details import AgentsExecutionScriptpadRunFunctionStartedDetails as AgentsExecutionScriptpadRunFunctionStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_completed_details import AgentsExecutionScriptpadSearchReplaceCompletedDetails as AgentsExecutionScriptpadSearchReplaceCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_started_details import AgentsExecutionScriptpadSearchReplaceStartedDetails as AgentsExecutionScriptpadSearchReplaceStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_write_completed_details import AgentsExecutionScriptpadWriteCompletedDetails as AgentsExecutionScriptpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_sort_field import AgentsExecutionSortField as AgentsExecutionSortField
from asteroid_odyssey.models.agents_execution_status import AgentsExecutionStatus as AgentsExecutionStatus
from asteroid_odyssey.models.agents_execution_terminal_payload import AgentsExecutionTerminalPayload as AgentsExecutionTerminalPayload
from asteroid_odyssey.models.agents_execution_transition_details import AgentsExecutionTransitionDetails as AgentsExecutionTransitionDetails
from asteroid_odyssey.models.agents_execution_trigger_context import AgentsExecutionTriggerContext as AgentsExecutionTriggerContext
from asteroid_odyssey.models.agents_execution_trigger_runner import AgentsExecutionTriggerRunner as AgentsExecutionTriggerRunner
from asteroid_odyssey.models.agents_execution_ui_trigger_context import AgentsExecutionUITriggerContext as AgentsExecutionUITriggerContext
from asteroid_odyssey.models.agents_execution_update_execution_status_request import AgentsExecutionUpdateExecutionStatusRequest as AgentsExecutionUpdateExecutionStatusRequest
from asteroid_odyssey.models.agents_execution_update_type import AgentsExecutionUpdateType as AgentsExecutionUpdateType
from asteroid_odyssey.models.agents_execution_updateable_status import AgentsExecutionUpdateableStatus as AgentsExecutionUpdateableStatus
from asteroid_odyssey.models.agents_execution_user_messages_add_text_body import AgentsExecutionUserMessagesAddTextBody as AgentsExecutionUserMessagesAddTextBody
from asteroid_odyssey.models.agents_execution_util_get_datetime_completed_details import AgentsExecutionUtilGetDatetimeCompletedDetails as AgentsExecutionUtilGetDatetimeCompletedDetails
from asteroid_odyssey.models.agents_execution_util_get_datetime_started_details import AgentsExecutionUtilGetDatetimeStartedDetails as AgentsExecutionUtilGetDatetimeStartedDetails
from asteroid_odyssey.models.agents_execution_workflow_update import AgentsExecutionWorkflowUpdate as AgentsExecutionWorkflowUpdate
from asteroid_odyssey.models.agents_files_file import AgentsFilesFile as AgentsFilesFile
from asteroid_odyssey.models.agents_files_temp_file import AgentsFilesTempFile as AgentsFilesTempFile
from asteroid_odyssey.models.agents_files_temp_files_response import AgentsFilesTempFilesResponse as AgentsFilesTempFilesResponse
from asteroid_odyssey.models.agents_graph_models_agent_graph import AgentsGraphModelsAgentGraph as AgentsGraphModelsAgentGraph
from asteroid_odyssey.models.agents_graph_models_nodes_node import AgentsGraphModelsNodesNode as AgentsGraphModelsNodesNode
from asteroid_odyssey.models.agents_graph_models_nodes_node_properties_union import AgentsGraphModelsNodesNodePropertiesUnion as AgentsGraphModelsNodesNodePropertiesUnion
from asteroid_odyssey.models.agents_graph_models_nodes_node_type import AgentsGraphModelsNodesNodeType as AgentsGraphModelsNodesNodeType
from asteroid_odyssey.models.agents_graph_models_nodes_position import AgentsGraphModelsNodesPosition as AgentsGraphModelsNodesPosition
from asteroid_odyssey.models.agents_graph_models_nodes_properties_api_method import AgentsGraphModelsNodesPropertiesAPIMethod as AgentsGraphModelsNodesPropertiesAPIMethod
from asteroid_odyssey.models.agents_graph_models_nodes_properties_api_properties import AgentsGraphModelsNodesPropertiesAPIProperties as AgentsGraphModelsNodesPropertiesAPIProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_playwright_script_properties import AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties as AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_properties import AgentsGraphModelsNodesPropertiesIrisProperties as AgentsGraphModelsNodesPropertiesIrisProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_output_properties import AgentsGraphModelsNodesPropertiesOutputProperties as AgentsGraphModelsNodesPropertiesOutputProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_llm_var import AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVar as AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVar
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_llm_var_type import AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVarType as AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVarType
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_properties import AgentsGraphModelsNodesPropertiesPlaywrightScriptProperties as AgentsGraphModelsNodesPropertiesPlaywrightScriptProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_url_properties import AgentsGraphModelsNodesPropertiesURLProperties as AgentsGraphModelsNodesPropertiesURLProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_vesta_properties import AgentsGraphModelsNodesPropertiesVestaProperties as AgentsGraphModelsNodesPropertiesVestaProperties
from asteroid_odyssey.models.agents_graph_models_settings import AgentsGraphModelsSettings as AgentsGraphModelsSettings
from asteroid_odyssey.models.agents_graph_models_sticky_note import AgentsGraphModelsStickyNote as AgentsGraphModelsStickyNote
from asteroid_odyssey.models.agents_graph_models_transitions_properties_iris_properties import AgentsGraphModelsTransitionsPropertiesIrisProperties as AgentsGraphModelsTransitionsPropertiesIrisProperties
from asteroid_odyssey.models.agents_graph_models_transitions_properties_outcome_success_properties import AgentsGraphModelsTransitionsPropertiesOutcomeSuccessProperties as AgentsGraphModelsTransitionsPropertiesOutcomeSuccessProperties
from asteroid_odyssey.models.agents_graph_models_transitions_properties_selector_properties import AgentsGraphModelsTransitionsPropertiesSelectorProperties as AgentsGraphModelsTransitionsPropertiesSelectorProperties
from asteroid_odyssey.models.agents_graph_models_transitions_transition import AgentsGraphModelsTransitionsTransition as AgentsGraphModelsTransitionsTransition
from asteroid_odyssey.models.agents_graph_models_transitions_transition_properties_union import AgentsGraphModelsTransitionsTransitionPropertiesUnion as AgentsGraphModelsTransitionsTransitionPropertiesUnion
from asteroid_odyssey.models.agents_graph_models_transitions_transition_type import AgentsGraphModelsTransitionsTransitionType as AgentsGraphModelsTransitionsTransitionType
from asteroid_odyssey.models.agents_graph_models_type_input_method import AgentsGraphModelsTypeInputMethod as AgentsGraphModelsTypeInputMethod
from asteroid_odyssey.models.agents_profile_agent_profile import AgentsProfileAgentProfile as AgentsProfileAgentProfile
from asteroid_odyssey.models.agents_profile_cookie import AgentsProfileCookie as AgentsProfileCookie
from asteroid_odyssey.models.agents_profile_country_code import AgentsProfileCountryCode as AgentsProfileCountryCode
from asteroid_odyssey.models.agents_profile_create_agent_profile_request import AgentsProfileCreateAgentProfileRequest as AgentsProfileCreateAgentProfileRequest
from asteroid_odyssey.models.agents_profile_credential import AgentsProfileCredential as AgentsProfileCredential
from asteroid_odyssey.models.agents_profile_credential_update import AgentsProfileCredentialUpdate as AgentsProfileCredentialUpdate
from asteroid_odyssey.models.agents_profile_custom_proxy_config_input import AgentsProfileCustomProxyConfigInput as AgentsProfileCustomProxyConfigInput
from asteroid_odyssey.models.agents_profile_custom_proxy_config_output import AgentsProfileCustomProxyConfigOutput as AgentsProfileCustomProxyConfigOutput
from asteroid_odyssey.models.agents_profile_duplicate_agent_profile_request import AgentsProfileDuplicateAgentProfileRequest as AgentsProfileDuplicateAgentProfileRequest
from asteroid_odyssey.models.agents_profile_operating_system import AgentsProfileOperatingSystem as AgentsProfileOperatingSystem
from asteroid_odyssey.models.agents_profile_proxy_mode import AgentsProfileProxyMode as AgentsProfileProxyMode
from asteroid_odyssey.models.agents_profile_proxy_type import AgentsProfileProxyType as AgentsProfileProxyType
from asteroid_odyssey.models.agents_profile_same_site import AgentsProfileSameSite as AgentsProfileSameSite
from asteroid_odyssey.models.agents_profile_sort_field import AgentsProfileSortField as AgentsProfileSortField
from asteroid_odyssey.models.agents_profile_update_agent_profile_request import AgentsProfileUpdateAgentProfileRequest as AgentsProfileUpdateAgentProfileRequest
from asteroid_odyssey.models.agents_schema_validate_schema_request import AgentsSchemaValidateSchemaRequest as AgentsSchemaValidateSchemaRequest
from asteroid_odyssey.models.agents_schema_validate_schema_response import AgentsSchemaValidateSchemaResponse as AgentsSchemaValidateSchemaResponse
from asteroid_odyssey.models.agents_workflow_browser_provider import AgentsWorkflowBrowserProvider as AgentsWorkflowBrowserProvider
from asteroid_odyssey.models.agents_workflow_browser_template_config import AgentsWorkflowBrowserTemplateConfig as AgentsWorkflowBrowserTemplateConfig
from asteroid_odyssey.models.agents_workflow_create_workflow_request import AgentsWorkflowCreateWorkflowRequest as AgentsWorkflowCreateWorkflowRequest
from asteroid_odyssey.models.agents_workflow_create_workflow_response import AgentsWorkflowCreateWorkflowResponse as AgentsWorkflowCreateWorkflowResponse
from asteroid_odyssey.models.agents_workflow_environment_template import AgentsWorkflowEnvironmentTemplate as AgentsWorkflowEnvironmentTemplate
from asteroid_odyssey.models.agents_workflow_environment_template_config import AgentsWorkflowEnvironmentTemplateConfig as AgentsWorkflowEnvironmentTemplateConfig
from asteroid_odyssey.models.agents_workflow_environment_type import AgentsWorkflowEnvironmentType as AgentsWorkflowEnvironmentType
from asteroid_odyssey.models.agents_workflow_execute_workflow_request import AgentsWorkflowExecuteWorkflowRequest as AgentsWorkflowExecuteWorkflowRequest
from asteroid_odyssey.models.agents_workflow_execute_workflow_response import AgentsWorkflowExecuteWorkflowResponse as AgentsWorkflowExecuteWorkflowResponse
from asteroid_odyssey.models.agents_workflow_os_provider import AgentsWorkflowOsProvider as AgentsWorkflowOsProvider
from asteroid_odyssey.models.agents_workflow_os_template_config import AgentsWorkflowOsTemplateConfig as AgentsWorkflowOsTemplateConfig
from asteroid_odyssey.models.agents_workflow_publish_workflow_response import AgentsWorkflowPublishWorkflowResponse as AgentsWorkflowPublishWorkflowResponse
from asteroid_odyssey.models.agents_workflow_sync_execution_request import AgentsWorkflowSyncExecutionRequest as AgentsWorkflowSyncExecutionRequest
from asteroid_odyssey.models.agents_workflow_sync_execution_response import AgentsWorkflowSyncExecutionResponse as AgentsWorkflowSyncExecutionResponse
from asteroid_odyssey.models.agents_workflow_workflow_ref import AgentsWorkflowWorkflowRef as AgentsWorkflowWorkflowRef
from asteroid_odyssey.models.agents_workflow_workflow_snapshot import AgentsWorkflowWorkflowSnapshot as AgentsWorkflowWorkflowSnapshot
from asteroid_odyssey.models.common_bad_request_error_body import CommonBadRequestErrorBody as CommonBadRequestErrorBody
from asteroid_odyssey.models.common_error import CommonError as CommonError
from asteroid_odyssey.models.common_forbidden_error_body import CommonForbiddenErrorBody as CommonForbiddenErrorBody
from asteroid_odyssey.models.common_internal_server_error_body import CommonInternalServerErrorBody as CommonInternalServerErrorBody
from asteroid_odyssey.models.common_not_found_error_body import CommonNotFoundErrorBody as CommonNotFoundErrorBody
from asteroid_odyssey.models.common_os_error import CommonOSError as CommonOSError
from asteroid_odyssey.models.common_sort_direction import CommonSortDirection as CommonSortDirection
from asteroid_odyssey.models.common_unauthorized_error_body import CommonUnauthorizedErrorBody as CommonUnauthorizedErrorBody
from asteroid_odyssey.models.executions_list200_response import ExecutionsList200Response as ExecutionsList200Response
from asteroid_odyssey.models.version import Version as Version



# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AgentsExecutionActionName(str, Enum):
    """
    AgentsExecutionActionName
    """

    """
    allowed enum values
    """
    ELEMENT_CLICK = 'element_click'
    ELEMENT_TYPE = 'element_type'
    ELEMENT_SELECT = 'element_select'
    ELEMENT_HOVER = 'element_hover'
    ELEMENT_DRAG = 'element_drag'
    ELEMENT_WAIT = 'element_wait'
    ELEMENT_FILL_FORM = 'element_fill_form'
    ELEMENT_GET_TEXT = 'element_get_text'
    ELEMENT_FILE_UPLOAD = 'element_file_upload'
    COORD_MOVE = 'coord_move'
    COORD_CLICK = 'coord_click'
    COORD_DOUBLE_CLICK = 'coord_double_click'
    COORD_DRAG = 'coord_drag'
    COORD_SCROLL = 'coord_scroll'
    NAV_TO = 'nav_to'
    NAV_BACK = 'nav_back'
    NAV_REFRESH = 'nav_refresh'
    NAV_TABS = 'nav_tabs'
    NAV_CLOSE_BROWSER = 'nav_close_browser'
    NAV_RESIZE_BROWSER = 'nav_resize_browser'
    NAV_INSTALL_BROWSER = 'nav_install_browser'
    NAV_ZOOM_IN = 'nav_zoom_in'
    NAV_ZOOM_OUT = 'nav_zoom_out'
    OBS_SNAPSHOT = 'obs_snapshot'
    OBS_SNAPSHOT_WITH_SELECTORS = 'obs_snapshot_with_selectors'
    OBS_SCREENSHOT = 'obs_screenshot'
    OBS_CONSOLE_MESSAGES = 'obs_console_messages'
    OBS_NETWORK_REQUESTS = 'obs_network_requests'
    OBS_EXTRACT_HTML = 'obs_extract_html'
    SCRIPT_EVAL = 'script_eval'
    SCRIPT_PLAYWRIGHT = 'script_playwright'
    SCRIPT_PLAYWRIGHT_LLM_VARS = 'script_playwright_llm_vars'
    SCRIPT_HYBRID_PLAYWRIGHT = 'script_hybrid_playwright'
    BROWSER_PRESS_KEY = 'browser_press_key'
    BROWSER_HANDLE_DIALOG = 'browser_handle_dialog'
    BROWSER_READ_CLIPBOARD = 'browser_read_clipboard'
    BROWSER_SOLVE_CAPTCHA = 'browser_solve_captcha'
    FILE_LIST = 'file_list'
    FILE_READ = 'file_read'
    FILE_STAGE = 'file_stage'
    FILE_DOWNLOAD = 'file_download'
    FILE_PDF_SAVE = 'file_pdf_save'
    SCRATCHPAD_READ = 'scratchpad_read'
    SCRATCHPAD_WRITE = 'scratchpad_write'
    SCRIPTPAD_RUN_FUNCTION = 'scriptpad_run_function'
    SCRIPTPAD_SEARCH_REPLACE = 'scriptpad_search_replace'
    SCRIPTPAD_READ = 'scriptpad_read'
    SCRIPTPAD_WRITE = 'scriptpad_write'
    EXT_GOOGLE_SHEETS_GET_DATA = 'ext_google_sheets_get_data'
    EXT_GOOGLE_SHEETS_SET_VALUE = 'ext_google_sheets_set_value'
    EXT_GET_MAIL = 'ext_get_mail'
    EXT_API_CALL = 'ext_api_call'
    UTIL_WAIT_TIME = 'util_wait_time'
    UTIL_GET_DATETIME = 'util_get_datetime'
    UTIL_GENERATE_TOTP_SECRET = 'util_generate_totp_secret'
    UTIL_SEND_USER_MESSAGE = 'util_send_user_message'
    AGENT_QUERY_CONTEXT = 'agent_query_context'
    AGENT_COMPILE_WORKFLOW = 'agent_compile_workflow'
    LLM_CALL = 'llm_call'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AgentsExecutionActionName from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from asteroid_odyssey.models.agents_files_temp_file import AgentsFilesTempFile
from typing import Optional, Set
from typing_extensions import Self

class AgentsWorkflowExecuteWorkflowRequest(BaseModel):
    """
    Request to execute a workflow by ID
    """ # noqa: E501
    input_variables: Optional[Dict[str, Any]] = Field(default=None, description="Input variables to be merged into the placeholders defined in prompts", alias="inputVariables")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Optional metadata key-value pairs for organizing and filtering executions")
    agent_profile_id: Optional[StrictStr] = Field(default=None, description="The ID of the agent profile to use. Note this is not the agent ID", alias="agentProfileId")
    agent_profile_pool_id: Optional[StrictStr] = Field(default=None, description="The ID of the agent profile pool to select a profile from. Mutually exclusive with agentProfileId.", alias="agentProfilePoolId")
    temp_files: Optional[List[AgentsFilesTempFile]] = Field(default=None, description="Array of temporary files to attach to the execution. Must have been pre-uploaded using the stage file endpoint", alias="tempFiles")
    __properties: ClassVar[List[str]] = ["inputVariables", "metadata", "agentProfileId", "agentProfilePoolId", "tempFiles"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsWorkflowExecuteWorkflowRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in temp_files (list)
        _items = []
        if self.temp_files:
            for _item_temp_files in self.temp_files:
                if _item_temp_files:
                    _items.append(_item_temp_files.to_dict())
            _dict['tempFiles'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsWorkflowExecuteWorkflowRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "inputVariables": obj.get("inputVariables"),
            "metadata": obj.get("metadata"),
            "agentProfileId": obj.get("agentProfileId"),
            "agentProfilePoolId": obj.get("agentProfilePoolId"),
            "tempFiles": [AgentsFilesTempFile.from_dict(_item) for _item in obj["tempFiles"]] if obj.get("tempFiles") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from asteroid_odyssey.models.agents_profile_cookie import AgentsProfileCookie
from asteroid_odyssey.models.agents_profile_country_code import AgentsProfileCountryCode
from asteroid_odyssey.models.agents_profile_credential import AgentsProfileCredential
from asteroid_odyssey.models.agents_profile_credential_update import AgentsProfileCredentialUpdate
from asteroid_odyssey.models.agents_profile_custom_proxy_config_input import AgentsProfileCustomProxyConfigInput
from asteroid_odyssey.models.agents_profile_operating_system import AgentsProfileOperatingSystem
from asteroid_odyssey.models.agents_profile_proxy_mode import AgentsProfileProxyMode
from asteroid_odyssey.models.agents_profile_proxy_type import AgentsProfileProxyType
from typing import Optional, Set
from typing_extensions import Self

class AgentsProfileUpdateAgentProfileRequest(BaseModel):
    """
    Request to update an existing agent profile
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, description="New name for the profile")
    description: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="New description for the profile")
    proxy_mode: Optional[AgentsProfileProxyMode] = Field(default=None, description="Proxy configuration mode", alias="proxyMode")
    proxy_cc: Optional[AgentsProfileCountryCode] = Field(default=None, description="Country code for proxy location (for managed proxy mode)", alias="proxyCC")
    proxy_type: Optional[AgentsProfileProxyType] = Field(default=None, description="Type of managed proxy to use (for managed proxy mode)", alias="proxyType")
    custom_proxy: Optional[AgentsProfileCustomProxyConfigInput] = Field(default=None, description="Custom proxy configuration (for custom proxy mode)", alias="customProxy")
    tailscale_auth_key: Optional[StrictStr] = Field(default=None, description="Tailscale auth key for VPN access (for tailscale proxy mode)", alias="tailscaleAuthKey")
    captcha_solver_active: Optional[StrictBool] = Field(default=None, description="Whether the captcha solver should be active (managed proxy only)", alias="captchaSolverActive")
    operating_system: Optional[AgentsProfileOperatingSystem] = Field(default=None, description="Operating system to emulate", alias="operatingSystem")
    extra_stealth: Optional[StrictBool] = Field(default=None, description="Whether to enable extra stealth mode", alias="extraStealth")
    cache_persistence: Optional[StrictBool] = Field(default=None, description="Whether to persist browser cache between sessions", alias="cachePersistence")
    adblock_active: Optional[StrictBool] = Field(default=None, description="Whether to enable ad blocking", alias="adblockActive")
    popup_blocker_active: Optional[StrictBool] = Field(default=None, description="Whether to enable popup blocking (requires adblock to be active)", alias="popupBlockerActive")
    force_popups_as_tabs_active: Optional[StrictBool] = Field(default=None, description="Whether to force popups to open as tabs", alias="forcePopupsAsTabsActive")
    media_blocker_active: Optional[StrictBool] = Field(default=None, description="Whether to enable media blocking (images, videos, etc.)", alias="mediaBlockerActive")
    pdf_viewer_active: Optional[StrictBool] = Field(default=None, description="Whether to enable the built-in PDF viewer (if disabled, PDFs are downloaded)", alias="pdfViewerActive")
    tracing_enabled: Optional[StrictBool] = Field(default=None, description="Whether browser tracing is enabled (admin only)", alias="tracingEnabled")
    credentials_to_add: Optional[List[AgentsProfileCredential]] = Field(default=None, description="Credentials to add to the profile", alias="credentialsToAdd")
    credentials_to_update: Optional[List[AgentsProfileCredentialUpdate]] = Field(default=None, description="Credentials to update by name (matched case-insensitively)", alias="credentialsToUpdate")
    credentials_to_delete: Optional[List[StrictStr]] = Field(default=None, description="IDs of credentials to remove from the profile", alias="credentialsToDelete")
    cookies_to_add: Optional[List[AgentsProfileCookie]] = Field(default=None, description="Cookies to add to the profile", alias="cookiesToAdd")
    cookies_to_delete: Optional[List[StrictStr]] = Field(default=None, description="IDs of cookies to remove from the profile", alias="cookiesToDelete")
    __properties: ClassVar[List[str]] = ["name", "description", "proxyMode", "proxyCC", "proxyType", "customProxy", "tailscaleAuthKey", "captchaSolverActive", "operatingSystem", "extraStealth", "cachePersistence", "adblockActive", "popupBlockerActive", "forcePopupsAsTabsActive", "mediaBlockerActive", "pdfViewerActive", "tracingEnabled", "credentialsToAdd", "credentialsToUpdate", "credentialsToDelete", "cookiesToAdd", "cookiesToDelete"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsProfileUpdateAgentProfileRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of custom_proxy
        if self.custom_proxy:
            _dict['customProxy'] = self.custom_proxy.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in credentials_to_add (list)
        _items = []
        if self.credentials_to_add:
            for _item_credentials_to_add in self.credentials_to_add:
                if _item_credentials_to_add:
                    _items.append(_item_credentials_to_add.to_dict())
            _dict['credentialsToAdd'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in credentials_to_update (list)
        _items = []
        if self.credentials_to_update:
            for _item_credentials_to_update in self.credentials_to_update:
                if _item_credentials_to_update:
                    _items.append(_item_credentials_to_update.to_dict())
            _dict['credentialsToUpdate'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in cookies_to_add (list)
        _items = []
        if self.cookies_to_add:
            for _item_cookies_to_add in self.cookies_to_add:
                if _item_cookies_to_add:
                    _items.append(_item_cookies_to_add.to_dict())
            _dict['cookiesToAdd'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsProfileUpdateAgentProfileRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "proxyMode": obj.get("proxyMode"),
            "proxyCC": obj.get("proxyCC"),
            "proxyType": obj.get("proxyType"),
            "customProxy": AgentsProfileCustomProxyConfigInput.from_dict(obj["customProxy"]) if obj.get("customProxy") is not None else None,
            "tailscaleAuthKey": obj.get("tailscaleAuthKey"),
            "captchaSolverActive": obj.get("captchaSolverActive"),
            "operatingSystem": obj.get("operatingSystem"),
            "extraStealth": obj.get("extraStealth"),
            "cachePersistence": obj.get("cachePersistence"),
            "adblockActive": obj.get("adblockActive"),
            "popupBlockerActive": obj.get("popupBlockerActive"),
            "forcePopupsAsTabsActive": obj.get("forcePopupsAsTabsActive"),
            "mediaBlockerActive": obj.get("mediaBlockerActive"),
            "pdfViewerActive": obj.get("pdfViewerActive"),
            "tracingEnabled": obj.get("tracingEnabled"),
            "credentialsToAdd": [AgentsProfileCredential.from_dict(_item) for _item in obj["credentialsToAdd"]] if obj.get("credentialsToAdd") is not None else None,
            "credentialsToUpdate": [AgentsProfileCredentialUpdate.from_dict(_item) for _item in obj["credentialsToUpdate"]] if obj.get("credentialsToUpdate") is not None else None,
            "credentialsToDelete": obj.get("credentialsToDelete"),
            "cookiesToAdd": [AgentsProfileCookie.from_dict(_item) for _item in obj["cookiesToAdd"]] if obj.get("cookiesToAdd") is not None else None,
            "cookiesToDelete": obj.get("cookiesToDelete")
        })
        return _obj





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from asteroid_odyssey.models.agents_execution_agent_query_context_started_details import AgentsExecutionAgentQueryContextStartedDetails
from asteroid_odyssey.models.agents_execution_llm_call_started_details import AgentsExecutionLLMCallStartedDetails
from asteroid_odyssey.models.agents_execution_nav_to_started_details import AgentsExecutionNavToStartedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_read_started_details import AgentsExecutionScratchpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_started_details import AgentsExecutionScratchpadWriteStartedDetails
from asteroid_odyssey.models.agents_execution_script_eval_started_details import AgentsExecutionScriptEvalStartedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_started_details import AgentsExecutionScriptHybridPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_started_details import AgentsExecutionScriptPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_started_details import AgentsExecutionScriptpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_run_function_started_details import AgentsExecutionScriptpadRunFunctionStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_started_details import AgentsExecutionScriptpadSearchReplaceStartedDetails
from asteroid_odyssey.models.agents_execution_util_get_datetime_started_details import AgentsExecutionUtilGetDatetimeStartedDetails
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

AGENTSEXECUTIONACTIVITYACTIONSTARTEDINFO_ONE_OF_SCHEMAS = ["AgentsExecutionAgentQueryContextStartedDetails", "AgentsExecutionLLMCallStartedDetails", "AgentsExecutionNavToStartedDetails", "AgentsExecutionScratchpadReadStartedDetails", "AgentsExecutionScratchpadWriteStartedDetails", "AgentsExecutionScriptEvalStartedDetails", "AgentsExecutionScriptHybridPlaywrightStartedDetails", "AgentsExecutionScriptPlaywrightStartedDetails", "AgentsExecutionScriptpadReadStartedDetails", "AgentsExecutionScriptpadRunFunctionStartedDetails", "AgentsExecutionScriptpadSearchReplaceStartedDetails", "AgentsExecutionUtilGetDatetimeStartedDetails"]

class AgentsExecutionActivityActionStartedInfo(BaseModel):
    """
    AgentsExecutionActivityActionStartedInfo
    """
    # data type: AgentsExecutionNavToStartedDetails
    oneof_schema_1_validator: Optional[AgentsExecutionNavToStartedDetails] = None
    # data type: AgentsExecutionScratchpadReadStartedDetails
    oneof_schema_2_validator: Optional[AgentsExecutionScratchpadReadStartedDetails] = None
    # data type: AgentsExecutionScratchpadWriteStartedDetails
    oneof_schema_3_validator: Optional[AgentsExecutionScratchpadWriteStartedDetails] = None
    # data type: AgentsExecutionScriptpadRunFunctionStartedDetails
    oneof_schema_4_validator: Optional[AgentsExecutionScriptpadRunFunctionStartedDetails] = None
    # data type: AgentsExecutionScriptPlaywrightStartedDetails
    oneof_schema_5_validator: Optional[AgentsExecutionScriptPlaywrightStartedDetails] = None
    # data type: AgentsExecutionScriptHybridPlaywrightStartedDetails
    oneof_schema_6_validator: Optional[AgentsExecutionScriptHybridPlaywrightStartedDetails] = None
    # data type: AgentsExecutionScriptEvalStartedDetails
    oneof_schema_7_validator: Optional[AgentsExecutionScriptEvalStartedDetails] = None
    # data type: AgentsExecutionScriptpadSearchReplaceStartedDetails
    oneof_schema_8_validator: Optional[AgentsExecutionScriptpadSearchReplaceStartedDetails] = None
    # data type: AgentsExecutionUtilGetDatetimeStartedDetails
    oneof_schema_9_validator: Optional[AgentsExecutionUtilGetDatetimeStartedDetails] = None
    # data type: AgentsExecutionScriptpadReadStartedDetails
    oneof_schema_10_validator: Optional[AgentsExecutionScriptpadReadStartedDetails] = None
    # data type: AgentsExecutionLLMCallStartedDetails
    oneof_schema_11_validator: Optional[AgentsExecutionLLMCallStartedDetails] = None
    # data type: AgentsExecutionAgentQueryContextStartedDetails
    oneof_schema_12_validator: Optional[AgentsExecutionAgentQueryContextStartedDetails] = None
    actual_instance: Optional[Union[AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails]] = None
    one_of_schemas: Set[str] = { "AgentsExecutionAgentQueryContextStartedDetails", "AgentsExecutionLLMCallStartedDetails", "AgentsExecutionNavToStartedDetails", "AgentsExecutionScratchpadReadStartedDetails", "AgentsExecutionScratchpadWriteStartedDetails", "AgentsExecutionScriptEvalStartedDetails", "AgentsExecutionScriptHybridPlaywrightStartedDetails", "AgentsExecutionScriptPlaywrightStartedDetails", "AgentsExecutionScriptpadReadStartedDetails", "AgentsExecutionScriptpadRunFunctionStartedDetails", "AgentsExecutionScriptpadSearchReplaceStartedDetails", "AgentsExecutionUtilGetDatetimeStartedDetails" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = AgentsExecutionActivityActionStartedInfo.model_construct()
        error_messages = []
        match = 0
        # validate data type: AgentsExecutionNavToStartedDetails
        if not isinstance(v, AgentsExecutionNavToStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionNavToStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScratchpadReadStartedDetails
        if not isinstance(v, AgentsExecutionScratchpadReadStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScratchpadReadStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScratchpadWriteStartedDetails
        if not isinstance(v, AgentsExecutionScratchpadWriteStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScratchpadWriteStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadRunFunctionStartedDetails
        if not isinstance(v, AgentsExecutionScriptpadRunFunctionStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadRunFunctionStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptPlaywrightStartedDetails
        if not isinstance(v, AgentsExecutionScriptPlaywrightStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptPlaywrightStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptHybridPlaywrightStartedDetails
        if not isinstance(v, AgentsExecutionScriptHybridPlaywrightStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptHybridPlaywrightStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptEvalStartedDetails
        if not isinstance(v, AgentsExecutionScriptEvalStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptEvalStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadSearchReplaceStartedDetails
        if not isinstance(v, AgentsExecutionScriptpadSearchReplaceStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadSearchReplaceStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionUtilGetDatetimeStartedDetails
        if not isinstance(v, AgentsExecutionUtilGetDatetimeStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionUtilGetDatetimeStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadReadStartedDetails
        if not isinstance(v, AgentsExecutionScriptpadReadStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadReadStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionLLMCallStartedDetails
        if not isinstance(v, AgentsExecutionLLMCallStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionLLMCallStartedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionAgentQueryContextStartedDetails
        if not isinstance(v, AgentsExecutionAgentQueryContextStartedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionAgentQueryContextStartedDetails`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in AgentsExecutionActivityActionStartedInfo with oneOf schemas: AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in AgentsExecutionActivityActionStartedInfo with oneOf schemas: AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AgentsExecutionNavToStartedDetails
        try:
            instance.actual_instance = AgentsExecutionNavToStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScratchpadReadStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScratchpadReadStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScratchpadWriteStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScratchpadWriteStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadRunFunctionStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadRunFunctionStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptPlaywrightStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptPlaywrightStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptHybridPlaywrightStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptHybridPlaywrightStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptEvalStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptEvalStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadSearchReplaceStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadSearchReplaceStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionUtilGetDatetimeStartedDetails
        try:
            instance.actual_instance = AgentsExecutionUtilGetDatetimeStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadReadStartedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadReadStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionLLMCallStartedDetails
        try:
            instance.actual_instance = AgentsExecutionLLMCallStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionAgentQueryContextStartedDetails
        try:
            instance.actual_instance = AgentsExecutionAgentQueryContextStartedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into AgentsExecutionActivityActionStartedInfo with oneOf schemas: AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into AgentsExecutionActivityActionStartedInfo with oneOf schemas: AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AgentsExecutionAgentQueryContextStartedDetails, AgentsExecutionLLMCallStartedDetails, AgentsExecutionNavToStartedDetails, AgentsExecutionScratchpadReadStartedDetails, AgentsExecutionScratchpadWriteStartedDetails, AgentsExecutionScriptEvalStartedDetails, AgentsExecutionScriptHybridPlaywrightStartedDetails, AgentsExecutionScriptPlaywrightStartedDetails, AgentsExecutionScriptpadReadStartedDetails, AgentsExecutionScriptpadRunFunctionStartedDetails, AgentsExecutionScriptpadSearchReplaceStartedDetails, AgentsExecutionUtilGetDatetimeStartedDetails]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

# flake8: noqa
"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from asteroid_odyssey.models.agent_list200_response import AgentList200Response
from asteroid_odyssey.models.agent_profile_clear_browser_cache200_response import AgentProfileClearBrowserCache200Response
from asteroid_odyssey.models.agent_profiles_list200_response import AgentProfilesList200Response
from asteroid_odyssey.models.agents_agent_base import AgentsAgentBase
from asteroid_odyssey.models.agents_agent_execute_agent_request import AgentsAgentExecuteAgentRequest
from asteroid_odyssey.models.agents_agent_execute_agent_response import AgentsAgentExecuteAgentResponse
from asteroid_odyssey.models.agents_agent_sort_field import AgentsAgentSortField
from asteroid_odyssey.models.agents_docs_search_docs_request import AgentsDocsSearchDocsRequest
from asteroid_odyssey.models.agents_docs_search_docs_response import AgentsDocsSearchDocsResponse
from asteroid_odyssey.models.agents_docs_search_result import AgentsDocsSearchResult
from asteroid_odyssey.models.agents_execution_api_key_ref import AgentsExecutionAPIKeyRef
from asteroid_odyssey.models.agents_execution_api_trigger_context import AgentsExecutionAPITriggerContext
from asteroid_odyssey.models.agents_execution_action_name import AgentsExecutionActionName
from asteroid_odyssey.models.agents_execution_activity import AgentsExecutionActivity
from asteroid_odyssey.models.agents_execution_activity_action_completed_info import AgentsExecutionActivityActionCompletedInfo
from asteroid_odyssey.models.agents_execution_activity_action_completed_payload import AgentsExecutionActivityActionCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_action_failed_payload import AgentsExecutionActivityActionFailedPayload
from asteroid_odyssey.models.agents_execution_activity_action_started_info import AgentsExecutionActivityActionStartedInfo
from asteroid_odyssey.models.agents_execution_activity_action_started_payload import AgentsExecutionActivityActionStartedPayload
from asteroid_odyssey.models.agents_execution_activity_file_added_payload import AgentsExecutionActivityFileAddedPayload
from asteroid_odyssey.models.agents_execution_activity_generic_payload import AgentsExecutionActivityGenericPayload
from asteroid_odyssey.models.agents_execution_activity_payload_union import AgentsExecutionActivityPayloadUnion
from asteroid_odyssey.models.agents_execution_activity_playwright_script_generated_payload import AgentsExecutionActivityPlaywrightScriptGeneratedPayload
from asteroid_odyssey.models.agents_execution_activity_reasoning_payload import AgentsExecutionActivityReasoningPayload
from asteroid_odyssey.models.agents_execution_activity_status_changed_payload import AgentsExecutionActivityStatusChangedPayload
from asteroid_odyssey.models.agents_execution_activity_step_completed_payload import AgentsExecutionActivityStepCompletedPayload
from asteroid_odyssey.models.agents_execution_activity_step_started_payload import AgentsExecutionActivityStepStartedPayload
from asteroid_odyssey.models.agents_execution_activity_transitioned_node_payload import AgentsExecutionActivityTransitionedNodePayload
from asteroid_odyssey.models.agents_execution_activity_user_message_received_payload import AgentsExecutionActivityUserMessageReceivedPayload
from asteroid_odyssey.models.agents_execution_activity_workflow_updated_payload import AgentsExecutionActivityWorkflowUpdatedPayload
from asteroid_odyssey.models.agents_execution_agent_query_context_completed_details import AgentsExecutionAgentQueryContextCompletedDetails
from asteroid_odyssey.models.agents_execution_agent_query_context_started_details import AgentsExecutionAgentQueryContextStartedDetails
from asteroid_odyssey.models.agents_execution_awaiting_confirmation_payload import AgentsExecutionAwaitingConfirmationPayload
from asteroid_odyssey.models.agents_execution_cancel_reason import AgentsExecutionCancelReason
from asteroid_odyssey.models.agents_execution_cancelled_payload import AgentsExecutionCancelledPayload
from asteroid_odyssey.models.agents_execution_comment import AgentsExecutionComment
from asteroid_odyssey.models.agents_execution_completed_payload import AgentsExecutionCompletedPayload
from asteroid_odyssey.models.agents_execution_element_file_upload_completed_details import AgentsExecutionElementFileUploadCompletedDetails
from asteroid_odyssey.models.agents_execution_execution_result import AgentsExecutionExecutionResult
from asteroid_odyssey.models.agents_execution_ext_api_call_completed_details import AgentsExecutionExtApiCallCompletedDetails
from asteroid_odyssey.models.agents_execution_ext_get_mail_completed_details import AgentsExecutionExtGetMailCompletedDetails
from asteroid_odyssey.models.agents_execution_failed_payload import AgentsExecutionFailedPayload
from asteroid_odyssey.models.agents_execution_file_list_completed_details import AgentsExecutionFileListCompletedDetails
from asteroid_odyssey.models.agents_execution_file_read_completed_details import AgentsExecutionFileReadCompletedDetails
from asteroid_odyssey.models.agents_execution_file_stage_completed_details import AgentsExecutionFileStageCompletedDetails
from asteroid_odyssey.models.agents_execution_human_label import AgentsExecutionHumanLabel
from asteroid_odyssey.models.agents_execution_llm_call_purpose import AgentsExecutionLLMCallPurpose
from asteroid_odyssey.models.agents_execution_llm_call_started_details import AgentsExecutionLLMCallStartedDetails
from asteroid_odyssey.models.agents_execution_list_item import AgentsExecutionListItem
from asteroid_odyssey.models.agents_execution_nav_to_completed_details import AgentsExecutionNavToCompletedDetails
from asteroid_odyssey.models.agents_execution_nav_to_started_details import AgentsExecutionNavToStartedDetails
from asteroid_odyssey.models.agents_execution_node_details import AgentsExecutionNodeDetails
from asteroid_odyssey.models.agents_execution_node_output_item import AgentsExecutionNodeOutputItem
from asteroid_odyssey.models.agents_execution_obs_snapshot_with_selectors_completed_details import AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
from asteroid_odyssey.models.agents_execution_paused_payload import AgentsExecutionPausedPayload
from asteroid_odyssey.models.agents_execution_rules_details import AgentsExecutionRulesDetails
from asteroid_odyssey.models.agents_execution_schedule_ref import AgentsExecutionScheduleRef
from asteroid_odyssey.models.agents_execution_schedule_trigger_context import AgentsExecutionScheduleTriggerContext
from asteroid_odyssey.models.agents_execution_scratchpad_read_completed_details import AgentsExecutionScratchpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_read_started_details import AgentsExecutionScratchpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_completed_details import AgentsExecutionScratchpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_started_details import AgentsExecutionScratchpadWriteStartedDetails
from asteroid_odyssey.models.agents_execution_script_eval_completed_details import AgentsExecutionScriptEvalCompletedDetails
from asteroid_odyssey.models.agents_execution_script_eval_started_details import AgentsExecutionScriptEvalStartedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_completed_details import AgentsExecutionScriptHybridPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_started_details import AgentsExecutionScriptHybridPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_script_pad_run_function_completed_details import AgentsExecutionScriptPadRunFunctionCompletedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_completed_details import AgentsExecutionScriptPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_started_details import AgentsExecutionScriptPlaywrightStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_completed_details import AgentsExecutionScriptpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_started_details import AgentsExecutionScriptpadReadStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_run_function_started_details import AgentsExecutionScriptpadRunFunctionStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_completed_details import AgentsExecutionScriptpadSearchReplaceCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_started_details import AgentsExecutionScriptpadSearchReplaceStartedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_write_completed_details import AgentsExecutionScriptpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_sort_field import AgentsExecutionSortField
from asteroid_odyssey.models.agents_execution_status import AgentsExecutionStatus
from asteroid_odyssey.models.agents_execution_terminal_payload import AgentsExecutionTerminalPayload
from asteroid_odyssey.models.agents_execution_transition_details import AgentsExecutionTransitionDetails
from asteroid_odyssey.models.agents_execution_trigger_context import AgentsExecutionTriggerContext
from asteroid_odyssey.models.agents_execution_trigger_runner import AgentsExecutionTriggerRunner
from asteroid_odyssey.models.agents_execution_ui_trigger_context import AgentsExecutionUITriggerContext
from asteroid_odyssey.models.agents_execution_update_execution_status_request import AgentsExecutionUpdateExecutionStatusRequest
from asteroid_odyssey.models.agents_execution_update_type import AgentsExecutionUpdateType
from asteroid_odyssey.models.agents_execution_updateable_status import AgentsExecutionUpdateableStatus
from asteroid_odyssey.models.agents_execution_user_messages_add_text_body import AgentsExecutionUserMessagesAddTextBody
from asteroid_odyssey.models.agents_execution_util_get_datetime_completed_details import AgentsExecutionUtilGetDatetimeCompletedDetails
from asteroid_odyssey.models.agents_execution_util_get_datetime_started_details import AgentsExecutionUtilGetDatetimeStartedDetails
from asteroid_odyssey.models.agents_execution_workflow_update import AgentsExecutionWorkflowUpdate
from asteroid_odyssey.models.agents_files_file import AgentsFilesFile
from asteroid_odyssey.models.agents_files_temp_file import AgentsFilesTempFile
from asteroid_odyssey.models.agents_files_temp_files_response import AgentsFilesTempFilesResponse
from asteroid_odyssey.models.agents_graph_models_agent_graph import AgentsGraphModelsAgentGraph
from asteroid_odyssey.models.agents_graph_models_nodes_node import AgentsGraphModelsNodesNode
from asteroid_odyssey.models.agents_graph_models_nodes_node_properties_union import AgentsGraphModelsNodesNodePropertiesUnion
from asteroid_odyssey.models.agents_graph_models_nodes_node_type import AgentsGraphModelsNodesNodeType
from asteroid_odyssey.models.agents_graph_models_nodes_position import AgentsGraphModelsNodesPosition
from asteroid_odyssey.models.agents_graph_models_nodes_properties_api_method import AgentsGraphModelsNodesPropertiesAPIMethod
from asteroid_odyssey.models.agents_graph_models_nodes_properties_api_properties import AgentsGraphModelsNodesPropertiesAPIProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_playwright_script_properties import AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_properties import AgentsGraphModelsNodesPropertiesIrisProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_output_properties import AgentsGraphModelsNodesPropertiesOutputProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_llm_var import AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVar
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_llm_var_type import AgentsGraphModelsNodesPropertiesPlaywrightScriptLLMVarType
from asteroid_odyssey.models.agents_graph_models_nodes_properties_playwright_script_properties import AgentsGraphModelsNodesPropertiesPlaywrightScriptProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_url_properties import AgentsGraphModelsNodesPropertiesURLProperties
from asteroid_odyssey.models.agents_graph_models_nodes_properties_vesta_properties import AgentsGraphModelsNodesPropertiesVestaProperties
from asteroid_odyssey.models.agents_graph_models_settings import AgentsGraphModelsSettings
from asteroid_odyssey.models.agents_graph_models_sticky_note import AgentsGraphModelsStickyNote
from asteroid_odyssey.models.agents_graph_models_transitions_properties_iris_properties import AgentsGraphModelsTransitionsPropertiesIrisProperties
from asteroid_odyssey.models.agents_graph_models_transitions_properties_outcome_success_properties import AgentsGraphModelsTransitionsPropertiesOutcomeSuccessProperties
from asteroid_odyssey.models.agents_graph_models_transitions_properties_selector_properties import AgentsGraphModelsTransitionsPropertiesSelectorProperties
from asteroid_odyssey.models.agents_graph_models_transitions_transition import AgentsGraphModelsTransitionsTransition
from asteroid_odyssey.models.agents_graph_models_transitions_transition_properties_union import AgentsGraphModelsTransitionsTransitionPropertiesUnion
from asteroid_odyssey.models.agents_graph_models_transitions_transition_type import AgentsGraphModelsTransitionsTransitionType
from asteroid_odyssey.models.agents_graph_models_type_input_method import AgentsGraphModelsTypeInputMethod
from asteroid_odyssey.models.agents_profile_agent_profile import AgentsProfileAgentProfile
from asteroid_odyssey.models.agents_profile_cookie import AgentsProfileCookie
from asteroid_odyssey.models.agents_profile_country_code import AgentsProfileCountryCode
from asteroid_odyssey.models.agents_profile_create_agent_profile_request import AgentsProfileCreateAgentProfileRequest
from asteroid_odyssey.models.agents_profile_credential import AgentsProfileCredential
from asteroid_odyssey.models.agents_profile_credential_update import AgentsProfileCredentialUpdate
from asteroid_odyssey.models.agents_profile_custom_proxy_config_input import AgentsProfileCustomProxyConfigInput
from asteroid_odyssey.models.agents_profile_custom_proxy_config_output import AgentsProfileCustomProxyConfigOutput
from asteroid_odyssey.models.agents_profile_duplicate_agent_profile_request import AgentsProfileDuplicateAgentProfileRequest
from asteroid_odyssey.models.agents_profile_operating_system import AgentsProfileOperatingSystem
from asteroid_odyssey.models.agents_profile_proxy_mode import AgentsProfileProxyMode
from asteroid_odyssey.models.agents_profile_proxy_type import AgentsProfileProxyType
from asteroid_odyssey.models.agents_profile_same_site import AgentsProfileSameSite
from asteroid_odyssey.models.agents_profile_sort_field import AgentsProfileSortField
from asteroid_odyssey.models.agents_profile_update_agent_profile_request import AgentsProfileUpdateAgentProfileRequest
from asteroid_odyssey.models.agents_schema_validate_schema_request import AgentsSchemaValidateSchemaRequest
from asteroid_odyssey.models.agents_schema_validate_schema_response import AgentsSchemaValidateSchemaResponse
from asteroid_odyssey.models.agents_workflow_browser_provider import AgentsWorkflowBrowserProvider
from asteroid_odyssey.models.agents_workflow_browser_template_config import AgentsWorkflowBrowserTemplateConfig
from asteroid_odyssey.models.agents_workflow_create_workflow_request import AgentsWorkflowCreateWorkflowRequest
from asteroid_odyssey.models.agents_workflow_create_workflow_response import AgentsWorkflowCreateWorkflowResponse
from asteroid_odyssey.models.agents_workflow_environment_template import AgentsWorkflowEnvironmentTemplate
from asteroid_odyssey.models.agents_workflow_environment_template_config import AgentsWorkflowEnvironmentTemplateConfig
from asteroid_odyssey.models.agents_workflow_environment_type import AgentsWorkflowEnvironmentType
from asteroid_odyssey.models.agents_workflow_execute_workflow_request import AgentsWorkflowExecuteWorkflowRequest
from asteroid_odyssey.models.agents_workflow_execute_workflow_response import AgentsWorkflowExecuteWorkflowResponse
from asteroid_odyssey.models.agents_workflow_os_provider import AgentsWorkflowOsProvider
from asteroid_odyssey.models.agents_workflow_os_template_config import AgentsWorkflowOsTemplateConfig
from asteroid_odyssey.models.agents_workflow_publish_workflow_response import AgentsWorkflowPublishWorkflowResponse
from asteroid_odyssey.models.agents_workflow_sync_execution_request import AgentsWorkflowSyncExecutionRequest
from asteroid_odyssey.models.agents_workflow_sync_execution_response import AgentsWorkflowSyncExecutionResponse
from asteroid_odyssey.models.agents_workflow_workflow_ref import AgentsWorkflowWorkflowRef
from asteroid_odyssey.models.agents_workflow_workflow_snapshot import AgentsWorkflowWorkflowSnapshot
from asteroid_odyssey.models.common_bad_request_error_body import CommonBadRequestErrorBody
from asteroid_odyssey.models.common_error import CommonError
from asteroid_odyssey.models.common_forbidden_error_body import CommonForbiddenErrorBody
from asteroid_odyssey.models.common_internal_server_error_body import CommonInternalServerErrorBody
from asteroid_odyssey.models.common_not_found_error_body import CommonNotFoundErrorBody
from asteroid_odyssey.models.common_os_error import CommonOSError
from asteroid_odyssey.models.common_sort_direction import CommonSortDirection
from asteroid_odyssey.models.common_unauthorized_error_body import CommonUnauthorizedErrorBody
from asteroid_odyssey.models.executions_list200_response import ExecutionsList200Response
from asteroid_odyssey.models.version import Version
